@@ -2,7 +2,7 @@ __license__ = "GNU General Public License v3"
 __author__ = 'Hwaipy'
 __email__ = 'hwaipy@gmail.com'
 
-from interactionfreepy.core import IFLoop, IFDefinition, IFException, Invocation, Message, IFLoop
+from interactionfreepy.core import IFLoop, IFDefinition, IFException, Invocation, Message
 from interactionfreepy.broker import IFBroker
 from interactionfreepy.worker import IFWorker
 
