@@ -17,9 +17,9 @@ class IFDefinition:
     DISTRIBUTING_MODE_DIRECT = b'Direct'
     DISTRIBUTING_MODE_SERVICE = b'Service'
     HEARTBEAT_LIVETIME = 10
-    DEFAULT_PORT_TCP = 81
-    DEFAULT_PORT_WEBSOCKET_SSL = 82
-    DEFAULT_PORT_WEBSOCKET = 83
+    DEFAULT_PORT_TCP = 1081
+    DEFAULT_PORT_WEBSOCKET_SSL = 1082
+    DEFAULT_PORT_WEBSOCKET = 1083
 
 
 class IFException(Exception):
@@ -53,8 +53,7 @@ class IFLoop:
     @classmethod
     def tryStart(cls):
         if IFLoop.__runIfNot():
-            thread = Thread(target=IFLoop.getInstance().start)
-            thread.setDaemon(True)
+            thread = Thread(target=IFLoop.getInstance().start, daemon=True)
             thread.start()
             IFLoop.__loopingThread = thread
 
@@ -80,6 +79,7 @@ class IFLoop:
 
 class Message:
     MessageIDs = 0
+    __mutex__ = threading.Lock()
 
     @classmethod
     def newBrokerMessage(cls, invocation, serialization='Msgpack'):
@@ -116,11 +116,10 @@ class Message:
 
     @classmethod
     def __getAndIncrementID(cls):
-        __mutex__ = threading.Lock()
-        __mutex__.acquire()
+        Message.__mutex__.acquire()
         id = Message.MessageIDs
         Message.MessageIDs += 1
-        __mutex__.release()
+        Message.__mutex__.release()
         return id
 
     @classmethod
@@ -367,3 +366,15 @@ class IFAddress:
             ip = sp2[0]
             port = IFDefinition().DEFAULT_PORT_TCP if len(sp2) == 1 else sp2[1]
             return [protocol, ip, port]
+
+if __name__ == '__main__':
+    print('test Core')
+    inv = Invocation.newRequest('set', args=[i for i in range(100)] * 150000, kwargs={})
+    bs = inv.serialize()
+    print(len(bs))
+
+    import random
+    random.Random().randint(100000, 999999)
+
+    import sys
+    print(sys.path)
\ No newline at end of file
